#define _POSIX_C_SOURCE 200809L
#include <netdb.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/socket.h>
#include <sys/types.h>

uint8_t byte(uint32_t x, int b) {
  return (x >> (8 * b)) & 0xff;
}

int main(int argc, char * argv[]) {
  if (argc != 2) {
    fprintf(stderr, "usage: %s hostname\n", argv[0]);
    return EXIT_FAILURE;
  }
  struct addrinfo hints = {
    .ai_flags = AI_PASSIVE,
    .ai_family = AF_UNSPEC,
    .ai_socktype = SOCK_STREAM,
    .ai_protocol = 0,
    .ai_addrlen = 0,
    .ai_addr = NULL,
    .ai_canonname = NULL,
    .ai_next = NULL
  };
  struct addrinfo * candidates;
  int error_code = getaddrinfo(argv[1], "80", &hints, &candidates);
  if (error_code) {
    fprintf(stderr, "getaddrinfo: %s\n", gai_strerror(error_code));
    exit(EXIT_FAILURE);
  }
  struct addrinfo * p;
  for (p = candidates; p != NULL; p = p->ai_next) {
    if (p->ai_family == AF_INET) {
      struct sockaddr_in * a = (struct sockaddr_in *) p->ai_addr;
      uint32_t b = ntohl(a->sin_addr.s_addr);
      printf("IPv4 %d.%d.%d.%d\n", byte(b,3), byte(b,2), byte(b,1), byte(b,0));
    } else {
      // TODO: handle IPv6
      printf("unknown family %d\n", p->ai_family);
    }
  }
  freeaddrinfo(candidates);
  return EXIT_SUCCESS;
}
