#define _XOPEN_SOURCE

#include <assert.h>
#include <fcntl.h>
#include <limits.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <unistd.h>

#define buf_max_size (1 << 14)
int buf_file = -1;
unsigned char buf_buffer[buf_max_size];
int buf_pos;
int buf_size;

int buf_open(const char * fpath) {
  assert (buf_file == -1);
  assert (buf_max_size <= SSIZE_MAX);
  buf_file = open(fpath, O_RDONLY | O_NOCTTY);
  if (buf_file == -1) {
    fprintf(stderr, "%s ", fpath);
    perror("open");
    return 0;
  }
  buf_pos = buf_size = 0;
  return 1;
}

int buf_get() {
  assert (buf_file != -1);
  if (buf_pos == buf_size) {
    // Load more data.
    buf_pos = 0;
    buf_size = read(buf_file, buf_buffer, buf_max_size);
    if (buf_size == -1) {
      perror("read");
      return EOF;
    }
    if (buf_size == 0) return EOF;
  }
  return buf_buffer[buf_pos++];
}

void buf_close() {
  assert (buf_file != -1);
  int error = close(buf_file);
  if (error == -1) perror("buf_close");
  buf_file = -1;
}
