import java.util.*;

// Holds information about a thread. The name is {@code Task} to avoid any
// conflicts with {@code java.lang.Thread}.
class Task {
  int startTime;
  String name;
  int duration;
}

public class FifoScheduler {
  public static void main(String[] args) {
    // parse input
    Scanner scan = new Scanner(System.in);
    int n = scan.nextInt();
    Deque<Task> input = new ArrayDeque<>();
    while (scan.hasNext()) {
      Task t = new Task();
      t.startTime = scan.nextInt();
      t.name = scan.next();
      t.duration = scan.nextInt();
      input.addLast(t);
    }

    int time = 0; // initialize with simulation start time

    // Check whether the input is valid.
    { int lastTime = time;
      for (Task t : input) {
        if (t.startTime < lastTime) throw new IllegalArgumentException();
        lastTime = t.startTime;
      }
    }

    // schedule
    Deque<Task> active = new ArrayDeque<>();
    Task[] running = new Task[n];
    int runningCount = 0; // runningCount is the count of nonnull elements of running
    while (!active.isEmpty() || runningCount > 0 || !input.isEmpty()) {
      if (active.isEmpty() && runningCount == 0) {
        // small optimization: skip uninteresting time steps
        time = input.getFirst().startTime;
      }

      // Handle requests to create threads.
      while (true) {
        Task t = input.peekFirst();
        if (t == null || t.startTime > time) break;
        input.removeFirst();
        active.addLast(t);
      }

      // Check if threads finished.
      for (int i = 0; i < n; ++i) if (running[i] != null) {
        if (--running[i].duration > 0) continue;
        running[i] = null;
        --runningCount;
      }

      // Schedule work on available processing units.
      for (int i = 0; i < n && !active.isEmpty(); ++i) if (running[i] == null) {
        running[i] = active.removeFirst();
        ++runningCount;
      }

      // Report what is running
      if (runningCount > 0) {
        System.out.printf("@%d", time);
        for (int i = 0; i < n; ++i) if (running[i] != null) {
          System.out.printf(" %s:%d", running[i].name, i + 1);
        }
        System.out.printf("\n");
      }

      ++time;
    } // while (...)
  } // main
} // class
