import java.util.*;

// Holds information about a thread. The name is {@code Task} to avoid any
// conflicts with {@code java.lang.Thread}.
class Task {
  int startTime;
  String name;
  int duration;
}

public class RoundRobinScheduler {
  public static void main(String[] args) {
    // parse input
    Scanner scan = new Scanner(System.in);
    int n = scan.nextInt();
    Deque<Task> input = new ArrayDeque<>();
    while (scan.hasNext()) {
      Task t = new Task();
      t.startTime = scan.nextInt();
      t.name = scan.next();
      t.duration = scan.nextInt();
      input.addLast(t);
    }

    int time = 0; // initialize with simulation start time

    // Check whether the input is valid.
    { int lastTime = time;
      for (Task t : input) {
        if (t.startTime < lastTime) throw new IllegalArgumentException();
        lastTime = t.startTime;
      }
    }

    // schedule
    Deque<Task> active = new ArrayDeque<>();
    Deque<Task> running = new ArrayDeque<>();
    while (!active.isEmpty() || !running.isEmpty() || !input.isEmpty()) {
      if (active.isEmpty() && running.isEmpty()) {
        // small optimization: skip uninteresting time steps
        time = input.getFirst().startTime;
      }

      // Handle requests to create threads.
      while (true) {
        Task t = input.peekFirst();
        if (t == null || t.startTime > time) break;
        input.removeFirst();
        active.addLast(t);
      }

      // Put running tasks back in the queue, unless they finished.
      while (!running.isEmpty()) {
        Task t = running.removeFirst();
        if (--t.duration > 0) active.addLast(t);
      }

      // Schedule work (for one time step).
      for (int i = 0; i < n && !active.isEmpty(); ++i) {
        running.addLast(active.removeFirst());
      }

      // Report what is running
      if (!running.isEmpty()) {
        System.out.printf("@%d", time);
        int core = 0;
        for (Task t : running) System.out.printf(" %s:%d", t.name, ++core);
        System.out.printf("\n");
      }

      ++time;
    } // while (...)
  } // main
} // class
